==> apache-camel-3.18.3-src.zip: apache-camel-3.18.3/components/camel-wordpress/src/main/java/org/apache/camel/component/wordpress/api/service/impl/WordpressServiceTaxonomyAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.wordpress.api.service.impl;

import java.util.Map;

import org.apache.camel.component.wordpress.api.model.Context;
import org.apache.camel.component.wordpress.api.model.Taxonomy;
import org.apache.camel.component.wordpress.api.service.WordpressServiceTaxonomy;
import org.apache.camel.component.wordpress.api.service.spi.TaxonomySPI;

import static com.google.common.base.Preconditions.checkNotNull;
import static com.google.common.base.Strings.emptyToNull;

public class WordpressServiceTaxonomyAdapter extends AbstractWordpressServiceAdapter<TaxonomySPI>
        implements WordpressServiceTaxonomy {

    public WordpressServiceTaxonomyAdapter(String wordpressUrl, String apiVersion) {
        super(wordpressUrl, apiVersion);
    }

    @Override
    protected Class<TaxonomySPI> getSpiType() {
        return TaxonomySPI.class;
    }

    @Override
    public Map<String, Taxonomy> list(Context context, String postType) {
        return getSpi().list(this.getApiVersion(), context, postType);
    }

    @Override
    public Taxonomy retrieve(Context context, String taxonomy) {
        checkNotNull(emptyToNull(taxonomy), "Please define a taxonomy");
        return getSpi().retrieve(this.getApiVersion(), context, taxonomy);
    }

}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-wordpress/src/main/java/org/apache/camel/component/wordpress/api/service/impl/WordpressServiceTaxonomyAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.wordpress.api.service.impl;

import java.util.Map;

import org.apache.camel.component.wordpress.api.model.Context;
import org.apache.camel.component.wordpress.api.model.Taxonomy;
import org.apache.camel.component.wordpress.api.service.WordpressServiceTaxonomy;
import org.apache.camel.component.wordpress.api.service.spi.TaxonomySPI;
import org.apache.camel.util.ObjectHelper;

public class WordpressServiceTaxonomyAdapter extends AbstractWordpressServiceAdapter<TaxonomySPI>
        implements WordpressServiceTaxonomy {

    public WordpressServiceTaxonomyAdapter(String wordpressUrl, String apiVersion) {
        super(wordpressUrl, apiVersion);
    }

    @Override
    protected Class<TaxonomySPI> getSpiType() {
        return TaxonomySPI.class;
    }

    @Override
    public Map<String, Taxonomy> list(Context context, String postType) {
        return getSpi().list(this.getApiVersion(), context, postType);
    }

    @Override
    public Taxonomy retrieve(Context context, String taxonomy) {
        ObjectHelper.notNullOrEmpty(taxonomy, "Please define a taxonomy");
        return getSpi().retrieve(this.getApiVersion(), context, taxonomy);
    }

}
